#
# spec file for package python-extract-msg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-extract-msg
Version:        0.52.0
Release:        1.3
Summary:        Extracts emails and attachments saved in Microsoft Outlook's msg files
License:        GPL-3.0-only
URL:            https://github.com/TeamMsgExtractor/msg-extractor
Source:         %{url}/archive/v%{version}.tar.gz#/extract_msg-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module beautifulsoup4 >= 4.11.1}
BuildRequires:  %{python_module RTFDE >= 0.1.1}
BuildRequires:  %{python_module compressed_rtf >= 1.0.6}
BuildRequires:  %{python_module ebcdic >= 1.1.1}
BuildRequires:  %{python_module olefile >= 0.47}
BuildRequires:  %{python_module red-black-tree-mod >= 1.20}
BuildRequires:  %{python_module tzlocal >= 4.2}
# /SECTION
BuildRequires:  fdupes
Requires:       python-RTFDE >= 0.1.1
Requires:       python-beautifulsoup4 >= 4.11.1
Requires:       python-compressed_rtf >= 1.0.6
Requires:       python-ebcdic >= 1.1.1
Requires:       python-olefile >= 0.47
Requires:       python-red-black-tree-mod >= 1.20
Requires:       python-tzlocal >= 4.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
The python package extract-msg automates the extraction of key email
data (from, to, cc, date, subject, body) and the email’s attachments.

%prep
%autosetup -p1 -n msg-extractor-%{version}
sed -i '/\#\!\/usr\/bin\/env python3/d' extract_msg/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/extract_msg
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v tests.py

%post
%python_install_alternative extract_msg

%postun
%python_uninstall_alternative extract_msg

%files %{python_files}
%python_alternative %{_bindir}/extract_msg
%{python_sitelib}/extract_msg
%{python_sitelib}/extract_msg-%{version}.dist-info

%changelog
* Wed Oct 23 2024 Matej Cepl <mcepl@cepl.eu>
- Make running the test suite verbose.
* Wed Oct 23 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.52.0
  * Fix typo in string that prevented HTML body from generating from
    the plain text body properly.
  * Adjusted the behavior of `MSGFile.areStringsUnicode` to prioritize
    the property specified by the parent MSG files for MSG files that
    are embedded. Additionally, added a fallback to rely on whether or
    not there is a stream using the `001F` type to determine the
    property value if it is entirely missing.
  * Adjusted `OleWriter.fromMsg()` and `MSGFile.export()` to add the
    argument `allowBadEmbed` which helps to correct a few different
    issues that may appear in embedded MSG files. These corrections
    allow the embedded file to still be extracted and to open properly
    in Outlook.
  * In addition to the above, the errors that some of those corrections
    will suppress are now significantly more informative about what went
    wrong.
- from version 0.51.1
  * Add class type added in last version to known class types.
- from version 0.51.0
  * Add basic support for MSG class type `IPM.SkypeTeams.Message`.
- from version 0.50.1
  * Fix bug introduced in previous version.
- from version 0.50.0
  * Adjust html header code to replace non-ascii characters with escaped versions.
    Also adjusted plain text to html conversion to ensure non-ascii character
    from the body are encoded to escaped values to be safe.
  * Made some corrections to `NullDate`.
* Sat Sep 21 2024 Guang Yee <gyee@suse.com>
- Enable sle15_python_module_pythons.
* Tue Sep  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  * Version 0.49.0
